# RCSid:
#	$Id: Makefile.inc,v 1.44 1999/05/05 23:34:03 sjg Exp $
#
#	@(#) Copyright (c) 1995 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@quick.com.au
#

.ifndef _top_inc_
_top_inc_=yes
# Makefile.base lets them override things
.include "Makefile.base"

TOP?=/usr/local
prefix?=${TOP}
BASE?=${TOP}/src/sjg
SRCDIR?=${BASE}
SJGSRC?=${BASE}
BASEDIR?=$BASE
INCDIR?=${SRCDIR}/include
.ifmake install
LIBDIR?=${prefix}/lib
.endif
.if (${.CURDIR} != ${.OBJDIR})
# they remembered to do a make obj
LIBDIR?=${SRCDIR}/lib/${.OBJDIR:T}
.endif
LIBDIR?=${SRCDIR}/lib

.ifdef NOARCHIVE
# on non-dev systems we skip building the archive libs.
# lib${LIB}_pic.a gets updated whenever the .so.* does
# and is easier to track.
DLIBEXT?=_pic.a
.endif

LIBMISC?=${LIBDIR}/libmisc${DLIBEXT}
LIBNETBSD?=${LIBDIR}/libnetbsd${DLIBEXT}
LIBTCP?=${LIBDIR}/libtcp${DLIBEXT}
LIBSIG?=${LIBDIR}/libsig${DLIBEXT}
LIBSJG?=${LIBDIR}/libsjg${DLIBEXT}
LIBDBUG?=${LIBDIR}/libdbug${DLIBEXT}
LIBDMALLOC?=${LIBDIR}/libdmalloc${DLIBEXT}
LIBMALLOC?=${LIBDMALLOC}
LIBSSLFD?=${LIBDIR}/libsslfd${DLIBEXT}

.if exists(${LIBSSLFD:R}_pic.a) && !exists(${LIBSSLFD:R}.a)
DLIBEXT?=_pic.a
.endif
DLIBEXT?=.a

.if exists(${LIBNETBSD})
NETBSDLIB?= -lnetbsd
.endif
.if exists(${LIBSJG})
SJGLIB?= -lsjg
SJGLIBS?= ${SJGLIB}
.else
SJGLIBS?= ${MISCLIB} ${SIGLIB} ${DBUGLIB}
.endif
.if exists(${LIBMISC})
MISCLIB?= -lmisc
.endif
.if exists(${LIBTCP})
TCPLIB?= -ltcp
.endif
.if exists(${LIBSIG})
SIGLIB?= -lsig
.endif
.if exists(${LIBDBUG})
USE_DBUG?=yes
DBUGLIB?= -ldbug
.endif

.if exists(${LIBDMALLOC})
USE_DMALLOC?=yes
DMALLOCLIB?= -ldmalloc
# we want to use dmalloc in all its glory if we can
# as it finds lots of bugs :-)
.if ${USE_DMALLOC} != "no"
CFLAGS+= -DHAVE_DMALLOC_H
MALLOCLIB?= ${DMALLOCLIB}
.endif
.endif

SBINDIR?=${prefix}/sbin
LIBEXECDIR?=${prefix}/libexec
MANDIR?=${prefix}/man
ETCDIR?=${prefix}/etc

# work out our parent dir.
PDIR=${.CURDIR:H:T}
.if (${PDIR} == "sbin") || (${PDIR} == "lib") || (${PDIR} == "libexec") || (${PDIR} == "etc")
BINDIR?=${prefix}/${PDIR}
.endif
.ifdef PROG
.if (${PDIR} == "libexec")
MAN?=${PROG}.8
.else
MAN?=${PROG}.1
.endif
.endif
BINDIR?=${prefix}/bin
BINOWN?=root
BINGRP?=wheel
LIBOWN?=root
LIBGRP?=wheel
LIBMODE?=644
BINMODE?=755
.if exists(${BASE}/bmake/install-sh)
INSTALL=${BASE}/bmake/install-sh
.else
# hope it is in $PATH
INSTALL?=install.sh
.endif
.if ${BINOWN} == ""
BININSTALL_FLAGS=${COPY} ${STRIP} -m ${BINMODE}
.else
BININSTALL_FLAGS=${COPY} ${STRIP} -o ${BINOWN} -g ${BINGRP} -m ${BINMODE}
.endif
.if ${LIBOWN} == ""
LIBINSTALL_FLAGS=${COPY} -m ${LIBMODE}
.else
LIBINSTALL_FLAGS=${COPY} -o ${LIBOWN} -g ${LIBGRP} -m ${LIBMODE}
.endif
STRIP?=
COPY?=
.ifndef BSDOBJDIR
# if BSDOBJDIR is defined, we assume they know what they are doing.
# I use:
# BSDOBJDIR=/usr/local/obj
# BSDSRCDIR=/usr/local/src
# and typically make /usr/local/obj -> src/obj.${MACHINE}
# Note that these variables must be set to what /bin/pwd would print
# in those directories.
# This allows us to export the src read-only, and other hosts
# need only make /usr/local/obj a link to somewhere appropriate and do
# say:
# cd /usr/local/src/obj.i386/sjg &&
# 	find . -type d -print | cpio -pdm /usr/local/obj
# to be ready to rock and roll.
#
OBJMACHINE=yes
.endif

CFLAGS+= ${DBG} -I. -I${.CURDIR} -I${.CURDIR}/.. -I${INCDIR}

.if !exists(/usr/local/share/bin/cmt2doc.pl)
EXTRACT_MAN=no
.endif

.if exists(${SRCDIR}/Makefile.${MACHINE}.inc)
.include "${SRCDIR}/Makefile.${MACHINE}.inc"
.endif

.if exists(${.CURDIR}/../Makefile.${MACHINE}.inc)
.include "${.CURDIR}/../Makefile.${MACHINE}.inc"
.elif exists(${.CURDIR}/../../Makefile.${MACHINE}.inc)
.include "${.CURDIR}/../../Makefile.${MACHINE}.inc"
.elif exists(${.CURDIR}/../../../Makefile.${MACHINE}.inc)
.include "${.CURDIR}/../../../Makefile.${MACHINE}.inc"
.endif

CONFDIR?=${SRCDIR}/conf

.if exists(${CONFDIR}/${.OBJDIR:T}/Makefile.inc)
CFLAGS+= -I${CONFDIR}/${.OBJDIR:T} -I${CONFDIR}
.include "${CONFDIR}/${.OBJDIR:T}/Makefile.inc"
.else
.if exists(/usr/include/stdlib.h) || exists(${INCDIR}/stdlib.h)
CFLAGS+= -DHAVE_STDLIB_H
.endif
.if exists(/usr/include/snmp.h) || exists(${INCDIR}/snmp.h)
CFLAGS+= -DHAVE_SNMP_H
.endif
.endif

DBG?= -g

# some standard stuff for building other peoples packages.
.if exists(${.CURDIR}/src)
.PATH: ${.CURDIR}/src
CFLAGS+= -I. -I${.CURDIR} -I${.CURDIR}/src
.elif exists(${.CURDIR:H}/dist)
.if exists(${.CURDIR:H}/dist/${.CURDIR:T})
.PATH: ${.CURDIR:H}/dist/${.CURDIR:T}
CFLAGS+= -I${.CURDIR:H}/dist/${.CURDIR:T}
.else
.PATH: ${.CURDIR:H}/dist
.endif
CFLAGS+= -I${.CURDIR:H}/dist
.elif exists(${.CURDIR:H:H}/dist)
.if exists(${.CURDIR:H:H}/dist/${.CURDIR:T})
.PATH: ${.CURDIR:H:H}/dist/${.CURDIR:T}
CFLAGS+= -I${.CURDIR:H:H}/dist/${.CURDIR:T}
.else
.PATH: ${.CURDIR:H:H}/dist
.endif
CFLAGS+= -I${.CURDIR:H:H}/dist
.endif


.if defined(USE_FWTK) && (${USE_FWTK} != "no")
# prog wants FWTK if available
FWTKSRC?=${BASE}/fwtk
.if exists(${FWTKSRC}/lib/${.OBJDIR:T}/libfwtk${DLIBEXT})
LIBFWTK?=${FWTKSRC}/lib/${.OBJDIR:T}/libfwtk${DLIBEXT}
.elif exists(${FWTKSRC}/lib/obj.${MACHINE}/libfwtk${DLIBEXT})
LIBFWTK?=${FWTKSRC}/lib/obj.${MACHINE}/libfwtk${DLIBEXT}
.elif exists(${LIBDIR}/libfwtk${DLIBEXT})
LIBFWTK?=${LIBDIR}/libfwtk${DLIBEXT}
.endif

.if exists(${LIBFWTK})
LDADD+= -L${LIBFWTK:H} 
LIBFWSSL?=${LIBFWTK:H}/libfwssl${DLIBEXT}
.if exists(${LIBFWSSL}) && defined(USE_SSL) && (${USE_SSL} != "no")
FWSSLLIB?=-lfwssl
LDADD+= ${FWSSLLIB} 
.if !defined(LIB) || (${LIB} != "fwssl")
DPADD+= ${LIBFWSSL}
.endif
.endif
FWTKLIB?=-lfwtk
CFLAGS+= -I${FWTKSRC}/include
LDADD+= ${FWTKLIB}
.if !defined(LIB) || (${LIB} != "fwtk")
DPADD+= ${LIBFWTK}
.endif
.else
CFLAGS+= -DNO_FWTK
.endif
.endif

SSLTOP?=/usr/local/ssl
LIBCRYPTO?=${SSLTOP}/lib/libcrypto${DLIBEXT}
LIBSSL?=${SSLTOP}/lib/libssl${DLIBEXT}

.if defined(USE_SSL) && (${USE_SSL} != "no")
# prog wants to use SSL
.if exists(${LIBSSLFD}) && exists(${LIBCRYPTO})
CFLAGS+= -DUSE_SSL -DUSE_SSLFD -I${SSLTOP}/include
SSLLIB?=-lssl
CRYPTOLIB?=-lcrypto
SSLLIBS=${SSLLIB} ${CRYPTOLIB}
LDADD+= -L${LIBSSLFD:H} -lsslfd -L${LIBCRYPTO:H} ${SSLLIBS} 
DPADD+= ${LIBCRYPTO} ${LIBCRYPTO:H}/libssl${DLIBEXT}
.if !defined(LIB) || (${LIB} != "sslfd")
DPADD+= ${LIBSSLFD}
.endif
.endif
.endif

.if defined(USE_SKEY) && (${USE_SKEY} != "no")
# prog wants SKEY if available
.if exists(${LIBDIR}/libskey${DLIBEXT})
LIBSKEY?=${LIBDIR}/libskey${DLIBEXT}
.if exists(${BASE}/lib/skey)
SKEYSRC?=${BASE}/lib/skey
.endif
.else
LIBSKEY?=/usr/lib/libskey.a
.if exists(/usr/src/lib/libskey)
SKEYSRC?=/usr/src/lib/libskey
.endif
.endif
.if exists(${LIBSKEY})
CFLAGS+= -DSKEY -DUSE_SKEY
.ifdef SKEYSRC
CFLAGS+= -I${SKEYSRC}
.endif
LDADD+= -lskey
.if !defined(LIB) || (${LIB} != "skey")
DPADD+= ${LIBSKEY}
.endif
.endif
.endif

.ifdef USE_CRYPT
.if exists(/usr/lib/libcrypt.a)
LIBCRYPT?=/usr/lib/libcrypt.a
LDADD+= -lcrypt
DPADD+= ${LIBCRYPT}
.endif
.endif

# we normally don't use lex - too slow
.ifdef USE_LEX
.if exists(/usr/lib/libl.a)
LDADD+= -ll
.endif
.endif

.ifdef SUBDIR
# make sure destination exists
beforeinstall:
	test -d ${DESTDIR}${BINDIR} || ${INSTALL} -m 775 -d ${DESTDIR}${BINDIR}
.endif


LDADD+=${LDSTATIC} -L${LIBDIR} ${LIBS} ${SJGLIBS} ${MALLOCLIB} ${SJGLIBS} 

CFLAGS+= ${XDBG}
LIBRESOLV?=/usr/lib/libresolv${DLIBEXT}
.if exists(${LIBRESOLV})
LDADD+= ${RESOLVLIB}
.endif

LDADD+= ${SOCKETLIB}

LIBCOMPAT?=${LIBDIR}/libcompat${DLIBEXT}
.if !exists(${LIBCOMPAT}) && exists(${LIBDIR}/libcompat.a)
LIBCOMPAT=${LIBDIR}/libcompat.a
.endif
.ifndef LIB
.if defined(COMPATLIB) && !empty(COMPATLIB) && exists(${LIBCOMPAT})
LDADD+= ${COMPATLIB}
.if !defined(LIB) || (${LIB} != "compat")
DPADD+= ${LIBCOMPAT}
.endif
.endif
.endif
.endif	# _top_inc_
